==> haskell-casa-types-0.0.1-111-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-casa-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 casa-types
version:              0.0.1
visibility:           public
id:                   casa-types-0.0.1-DEeX8ZXogpq7X72AfOmkw8
key:                  casa-types-0.0.1-DEeX8ZXogpq7X72AfOmkw8
license:              BSD-3-Clause
copyright:            2018-2019 FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
synopsis:             Types for Casa
description:          Types for Casa <https://casa.fpcomplete.com/>
category:             Development
abi:                  3910a90d7b1abda2e10c4583c35c38a0
exposed:              True
exposed-modules:      Casa.Types
hidden-modules:       Paths_casa_types
import-dirs:          /usr/lib/ghc-8.10.2/site-local/casa-types-0.0.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/casa-types-0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/casa-types-0.0.1
hs-libraries:         HScasa-types-0.0.1-DEeX8ZXogpq7X72AfOmkw8
depends:
    aeson-1.5.4.1-A0L815KAfIF5MogEzEmc2
    attoparsec-0.13.2.4-6s9PGXpTa8d5vs3WhgDbsJ base-4.14.1.0
    base16-bytestring-0.1.1.7-7MnoTKrQfBC3WeMx0LqUK0
    bytestring-0.10.10.0 hashable-1.3.0.0-B2he7mV2CaG3Rgw4mjNDxl
    path-pieces-0.2.1-3qqfFRSZ4HL4UPuvUVZn5U
    persistent-2.10.5.2-9C7YDZgOZZdFI7RiMCAAZW text-1.2.3.2

haddock-interfaces:   /usr/share/doc/haskell-casa-types/html/casa-types.haddock
haddock-html:         /usr/share/doc/haskell-casa-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-casa-types-0.0.1-115-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-casa-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 casa-types
version:              0.0.1
visibility:           public
id:                   casa-types-0.0.1-KPgz2LuD8INEv1tulry325
key:                  casa-types-0.0.1-KPgz2LuD8INEv1tulry325
license:              BSD-3-Clause
copyright:            2018-2019 FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
synopsis:             Types for Casa
description:          Types for Casa <https://casa.fpcomplete.com/>
category:             Development
abi:                  9b4dc5138a96a67c087936f95fa63dce
exposed:              True
exposed-modules:      Casa.Types
hidden-modules:       Paths_casa_types
import-dirs:          /usr/lib/ghc-8.10.2/site-local/casa-types-0.0.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/casa-types-0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/casa-types-0.0.1
hs-libraries:         HScasa-types-0.0.1-KPgz2LuD8INEv1tulry325
depends:
    aeson-1.5.4.1-L4blGMy4f2B3cvSeFwSnLz
    attoparsec-0.13.2.4-KEyXx14pxg5Gm10vjvQskB base-4.14.1.0
    base16-bytestring-0.1.1.7-7MnoTKrQfBC3WeMx0LqUK0
    bytestring-0.10.10.0 hashable-1.3.0.0-Bw2FqVuLXcBEg9A9iLQwXN
    path-pieces-0.2.1-3qqfFRSZ4HL4UPuvUVZn5U
    persistent-2.11.0.0-DWJSTI2zOBo18xm98qA8dU text-1.2.3.2

haddock-interfaces:   /usr/share/doc/haskell-casa-types/html/casa-types.haddock
haddock-html:         /usr/share/doc/haskell-casa-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
